==> haskell-crypton-x509-validation-1.6.12-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509-validation
version:              1.6.12
visibility:           public
id:                   crypton-x509-validation-1.6.12-IK2fGlCe2Ph34I6lH5lXrJ
key:                  crypton-x509-validation-1.6.12-IK2fGlCe2Ph34I6lH5lXrJ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  2aab738a365458908fbfa3968d74f6de
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:
    /usr/lib/ghc-9.0.2/site-local/crypton-x509-validation-1.6.12

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/crypton-x509-validation-1.6.12

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-validation
hs-libraries:         HScrypton-x509-validation-1.6.12-IK2fGlCe2Ph34I6lH5lXrJ
depends:
    asn1-encoding-0.9.6-DwUky2iBreIC6bbIXJDOoo
    asn1-types-0.3.4-6wpoE5PoEIAJgIMZ40ZnuH base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    crypton-0.32-JkPj4NTo5F7CfmkMW2doQD
    crypton-x509-1.7.6-FKDle6vcmAi8HDLrboJuXG
    crypton-x509-store-1.6.9-KEWQ3oc5BCnBNJByOFeRN0
    data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO
    hourglass-0.2.12-CqLRJdRhgyi1F5J2Kbfwum
    memory-0.17.0-Ba80JGdi30PBt5EgUiQ1Tu mtl-2.2.2
    pem-0.2.4-4peApW3gfWj4GFBAgRMCEc

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-validation/html/crypton-x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-validation-1.6.12-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509-validation
version:              1.6.12
visibility:           public
id:                   crypton-x509-validation-1.6.12-3HUj1wvQz5pIDP2dRzWo89
key:                  crypton-x509-validation-1.6.12-3HUj1wvQz5pIDP2dRzWo89
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  20863c21aa1ce489046f927187df6d53
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:
    /usr/lib/ghc-9.0.2/site-local/crypton-x509-validation-1.6.12

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/crypton-x509-validation-1.6.12

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-validation
hs-libraries:         HScrypton-x509-validation-1.6.12-3HUj1wvQz5pIDP2dRzWo89
depends:
    asn1-encoding-0.9.6-AAtkw5TY9F8VurSKdIoeL
    asn1-types-0.3.4-aUYrrqmCzsAxNNdefID82 base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    crypton-0.32-I25Or2u1KXpL7IAB7bK2rz
    crypton-x509-1.7.6-C7Qr4M5ilfnDiz0UC7ZYag
    crypton-x509-store-1.6.9-86iOfXe0P7uLpyFO8WgCHc
    data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO
    hourglass-0.2.12-K23HUAH9IGt4VfhTMnFqml
    memory-0.17.0-Ba80JGdi30PBt5EgUiQ1Tu mtl-2.2.2
    pem-0.2.4-1mbRPloOMhKLwKtT5g0UYJ

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-validation/html/crypton-x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
